Struct farcaster_node::config::ParsedSwapConfig
source · Expand description
This struct is the result type returned by the config to a service for the pair of arbitrating
and accordant chain in a swap. E.g. for Bitcoin and Monero [swap.bitcoin...] is stored in
arbitrating and [swap.monero...] is stored in accordant.
Fields
arbitrating: ArbConfigSwap parameters for an arbitrating blockchain
accordant: AccConfigSwap parameters for an accordant blockchain