Module farcaster_node::config
source · Structs
Holds the parameters needed for an accordant asset in a swap, e.g. Monero
Holds the parameters needed for an arbitrating asset in a swap, e.g. Bitcoin
This struct holds the complete swap config for a chain
This struct is the result type returned by the config to a service for the pair of arbitrating
and accordant chain in a swap. E.g. for Bitcoin and Monero
[swap.bitcoin...] is stored in
arbitrating and [swap.monero...] is stored in accordant.This struct holds all swap config, for all chains and all networks
Defines a potential minimum and maximum amount for an asset, below or above which the user will
not accept the trade
Constants
Functions
Parse a configuration file and return a
Config